@@ -161,7 +161,7 @@ static inline void array_copy64(uint64_t *d, uint64_t *s, uint32_t nb)
 #ifdef __MINGW32__
   # define LITTLE_ENDIAN 1234
   # define BYTE_ORDER    LITTLE_ENDIAN
-#elif defined(__FreeBSD__) || defined(__DragonFly__)
+#elif defined(__FreeBSD__) || defined(__DragonFly__) || defined(__NetBSD__)
   # include <sys/endian.h>
 #elif defined(__OpenBSD__) || defined(__SVR4)
   # include <sys/types.h>
