@@ -126,7 +126,7 @@ void skein512_init(struct skein512_ctx *ctx, uint32_t hashlen)
 	uint64_t buf[8];
 	memset(ctx, 0, sizeof(*ctx));
 
-	ctx->hashlen = hashlen;
+	ctx->hashlen = (hashlen + 7) >> 3;
 	SET_TYPE(ctx, FLAG_FIRST | FLAG_FINAL | FLAG_TYPE(TYPE_CFG));
 	
 	memset(buf, '\0', sizeof(buf));
@@ -185,7 +185,7 @@ void skein512_finalize(struct skein512_ctx *ctx, uint8_t *out)
 	memset(ctx->buf, '\0', 64);
 
 	/* make sure we have a 8 bit rounded value */
-	outsize = (ctx->hashlen + 7) >> 3;
+	outsize = ctx->hashlen;
 
 	/* backup h[0--7] */
 	for (j = 0; j < 8; j++)
